@@ -1,5 +1,3 @@
-from sphinx.util.compat import Directive
-
 from noseOfYeti.tokeniser import Tokeniser, TokeniserCodec, determine_imports
 from support import spec_options
 
@@ -10,19 +8,20 @@ def enable(app):
         , without_should_dsl = config.get('noy_without_should_dsl')[0]
         , with_default_imports = not config.get('noy_no_default_imports')[0]
         )
-    
+
     tok = Tokeniser(
           default_kls = config.get('noy_default_kls')[0]
         , import_tokens = imports
-        , wrapped_setup = options.wrapped_setup
+        , wrapped_setup = config.get('noy_wrapped_setup')[0]
         , with_describe_attrs = not config.get('noy_no_describe_attrs')[0]
         )
-    
+
     TokeniserCodec(tok).register()
 
 def setup(app):
     for option, default in spec_options.for_sphinx().items():
         name = 'noy_%s' % option.replace('-', '_')
         app.add_config_value(name, default, 'html')
-    
+
     app.connect('builder-inited', enable)
+
