@@ -1,6 +1,6 @@
 from noseOfYeti.tokeniser.imports import determine_imports
-from tokenize import NEWLINE, NAME, OP
-from should_dsl import *
+from should_dsl import should
+from tokenize import NAME, OP
 
 class Test_DetermineImports(object):
     def test_extra_imports_are_added(self):
@@ -10,7 +10,7 @@ class Test_DetermineImports(object):
         ) |should| equal_to([
             (NAME, 'import'), (NAME, 'thing'), (OP, ';'), (NAME, 'import'), (NAME, 'stuff')
         ])
-    
+
     def test_extra_imports_added_before_defaults(self):
         extra_imports = "import thing; import stuff"
         determine_imports(
@@ -24,7 +24,7 @@ class Test_DetermineImports(object):
                 , (NAME, 'noseOfYeti'), (OP, '.'), (NAME, 'tokeniser'), (OP, '.'), (NAME, "support")
                 , (NAME, 'import'), (OP, '*')
         ])
-    
+
     def test_extra_imports_not_added_if_no_defaults(self):
         determine_imports(with_default_imports=True, without_should_dsl=True) |should| equal_to([
               (NAME, 'import'), (NAME, 'nose'), (OP, ';')
@@ -33,7 +33,7 @@ class Test_DetermineImports(object):
                 , (NAME, 'noseOfYeti'), (OP, '.'), (NAME, 'tokeniser'), (OP, '.'), (NAME, "support")
                 , (NAME, 'import'), (OP, '*')
         ])
-    
+
     def test_should_dsl_imports_added_if_specified(self):
         determine_imports(with_default_imports=True, without_should_dsl=False) |should| equal_to([
               (NAME, 'import'), (NAME, 'nose'), (OP, ';')
@@ -43,6 +43,7 @@ class Test_DetermineImports(object):
                 , (NAME, 'noseOfYeti'), (OP, '.'), (NAME, 'tokeniser'), (OP, '.'), (NAME, "support")
                 , (NAME, 'import'), (OP, '*')
         ])
-    
+
     def test_it_returns_nothing_if_no_imports(self):
-        determine_imports(with_default_imports=False, without_should_dsl=True) |should| equal_to([])
\ No newline at end of file
+        determine_imports(with_default_imports=False, without_should_dsl=True) |should| equal_to([])
+
